Australian Continental Championship 2006 Brisbane, Queensland, Australia October 1st 2006 3R+F 26 players Jason Ryan Crypt (12 cards, min=18, max=34, avg=6.58) ------------------------------------------ 3x Julia Prima 7 DOM OBT aus myt Kiasyd:2 3x Kassiym Malikhair 6 MYT OBT dom for Kiasyd:2 2x Marconius 9 DOM MYT OBT pot archbishop Kiasyd:2 2x Bartholomew 8 AUS MYT NEC dom obt Kiasyd:2 1x Béatrice L'Angou 5 MYT aus dom nec Kiasyd:2 1x Royce 1 dom Pander:2 Library (90 cards) Master (15) 1x Anarch Troublemaker 4x Blood Doll 1x Dominate 1x Giant's Blood 2x Hungry Coyote, The 1x KRCG News Radio 1x London Evening Star, Tabloid Newspaper 1x Momentum's Edge 1x Pentex(TM) Subversion 1x Rumor Mill, Tabloid Newspaper, The 1x WMRH Talk Radio Action (9) 2x Aranthebes, The Immortal 1x Dominate Kine 6x Govern the Unaligned Ally (1) 1x Mylan Horseed Equipment (2) 2x Sport Bike Action Modifier (10) 2x Bonding 2x Conditioning 2x Foreshadowing Destruction 4x Shadow Play Action Modifier/Reaction (9) 9x Aura Absorption Reaction (18) 3x Deflection 5x Eyes of the Night 10x Forced Awakening Combat (26) 2x Darkling Trickery 4x Darkness Within 13x Earth Swords 3x Entombment 4x Shadow Step